# Common problems

- Problems may occur due to incompatible [company_name] [solution_name] / [blackduck_product_name] versions. Consult the [Compatibility Matrix](https://sig-product-docs.synopsys.com/bundle/blackduck-compatibility/page/topics/Black-Duck-Release-Compatibility.html) to verify your combination. Attempting to reproduce the problem using the latest version of [company_name] [solution_name] with the latest version of [blackduck_product_name] might also assist in determining if the issue has been resolved.
- Remember to consider the possibility that the [blackduck_product_name] user lacks the necessary permissions (to create the project, update the BOM, receive notifications, etc.) in [blackduck_product_name]. For more information, see [Black Duck user role requirements](../gettingstarted/usersandroles.md).
- Confirm that the [blackduck_product_name] server (registration key) has the required capabilities enabled (binary upload, snippet scanning, etc.).

## Incorrect or missing components

- For issues related to tools invoked by [company_name] [solution_name] ([blackduck_signature_scanner_name], Docker Inspector, etc.), please check that tool's documentation.
- Issues related to incorrect components in the [blackduck_product_name] BOM.    
	- [company_name] [solution_name] configuration has control over matches produced by detectors (that are written to BDIO files), but no control over matches produced by the [blackduck_signature_scanner_name] / [blackduck_product_name]. When investigating an incorrect component in a [blackduck_product_name] BOM, you need to determine whether the component was contributed by a detector, or by the [blackduck_signature_scanner_name]: On the [blackduck_product_name] Components tab for the project/version: Click on the *N Matches* link next to the component. The next screen lists the matches on the right-hand side. Matches from the [blackduck_signature_scanner_name] have a filename in the *Name* column. Matches from detectors have an external ID (such as "org.hamcrest:hamcrest-core:1.3") in the *Name* column.
- For issues related to components missing from, or incorrectly categorized, in the [blackduck_product_name] BOM.    
	- [company_name] [solution_name] configuration has control over the production of BDIO files (use [--detect.diagnostic](../properties/configuration/debug.md#diagnostic-mode) to save these), but no control over how they are converted into a BOM by [blackduck_product_name]. A good first step is to determine whether the BDIO files produced are correct. If they are incorrect, the problem is related to what [company_name] [solution_name] is doing. If they are correct, but the BOM is incorrect, the problem is related to what [blackduck_product_name] is doing. Similarly, [company_name] [solution_name] is responsible for passing the correct arguments to the [blackduck_signature_scanner_name], but beyond that has no control over the results it produces.

## Spring Boot related issues

- [company_name] [solution_name] is a Spring Boot application, and leverages Spring Boot to provide various mechanisms to configure it through [property settings](https://docs.spring.io/spring-boot/docs/current/reference/html/boot-features-external-config.html). Spring Boot flexibility makes it's possible for [company_name] [solution_name] to be influenced by files (application.properties, application.xml, etc.) that might exist in the directory from which [company_name] [solution_name] is run that are intended for some other application and produce unexpected results. If properties have unexpected values (see the [company_name] [solution_name] log), this should be reviewed. The best solution may be to run [company_name] [solution_name] from a different empty directory using the `--detect.source.path argument` parameter.
- Similarly, [company_name] [solution_name] might be influenced by environment variables via the same Spring Boot mechanism, so check the environment for variables that correspond to [company_name] [solution_name] property names.

